==> okteta_0.25.5.orig.tar.xz: okteta-0.25.5/kasten/controllers/view/bytetable/bytetabletoolviewfactory.cpp <==
/*
    This file is part of the Kasten Framework, made within the KDE community.

    Copyright 2010 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#include "bytetabletoolviewfactory.h"

// lib
#include "bytetabletoolview.h"
#include "bytetabletool.h"
// KF5
#include <KLocalizedString>

namespace Kasten {

ByteTableToolViewFactory::ByteTableToolViewFactory() = default;

ByteTableToolViewFactory::~ByteTableToolViewFactory() = default;

QString ByteTableToolViewFactory::iconName() const { return QStringLiteral("table"); }
QString ByteTableToolViewFactory::title()    const { return i18nc("@title:window", "Value/Char Table"); }
QString ByteTableToolViewFactory::id()       const { return QStringLiteral("org.kde.okteta.ByteTableToolView"); }
SidePosition ByteTableToolViewFactory::defaultPosition() const { return RightSidePosition; }

AbstractToolView* ByteTableToolViewFactory::create(AbstractTool* tool)
{
    return new ByteTableToolView(qobject_cast<ByteTableTool*>(tool));
}

}

==> okteta_0.26.3.orig.tar.xz: okteta-0.26.3/kasten/controllers/view/bytetable/bytetabletoolviewfactory.cpp <==
/*
    This file is part of the Kasten Framework, made within the KDE community.

    Copyright 2010 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#include "bytetabletoolviewfactory.hpp"

// lib
#include "bytetabletoolview.hpp"
#include "bytetabletool.hpp"
// KF
#include <KLocalizedString>

namespace Kasten {

ByteTableToolViewFactory::ByteTableToolViewFactory() = default;

ByteTableToolViewFactory::~ByteTableToolViewFactory() = default;

QString ByteTableToolViewFactory::iconName() const { return QStringLiteral("table"); }
QString ByteTableToolViewFactory::title()    const { return i18nc("@title:window", "Value/Char Table"); }
QString ByteTableToolViewFactory::id()       const { return QStringLiteral("org.kde.okteta.ByteTableToolView"); }
SidePosition ByteTableToolViewFactory::defaultPosition() const { return RightSidePosition; }

AbstractToolView* ByteTableToolViewFactory::create(AbstractTool* tool) const
{
    return new ByteTableToolView(qobject_cast<ByteTableTool*>(tool));
}

}
